==> soliq_id-1.4.27.tar.gz: lib/src/screens/widgets/message_screen.dart <==
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:soliq_id/localizations_util.dart';
import 'dart:math' as math;

import '../../utils/assets.dart';
import '../../utils/color_utils.dart';
import '../../utils/progress_indicator/src/circular_step_progress_indicator.dart';
import 'custom_button.dart';


class MessageScreen extends StatelessWidget {
  final bool success;
  final String message;
  const MessageScreen({Key? key, required this.success, required this.message}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
        child: Stack(
          children: [
            Column(
              children: [
                Container(
                  margin: const EdgeInsets.all(35),
                  child: AspectRatio(
                      aspectRatio: 1.0 / 1,
                      child: CircularStepProgressIndicator(
                        totalSteps: 100,
                        currentStep: 100,
                        stepSize: 15,
                        selectedColor: Colors.grey.withOpacity(0.2),
                        unselectedColor: Colors.transparent,
                        padding: math.pi / 35,
                        child: Container(
                          margin: const EdgeInsets.symmetric(
                              horizontal: 70, vertical: 80),
                          child: SvgPicture.asset(success ? Assets.success_face : Assets.error_face),
                        ),
                      )),
                ),
                const SizedBox(
                  height: 30,
                ),
                Container(
                  height: 45,
                  width: MediaQuery.of(context).size.width,
                  margin: const EdgeInsets.symmetric(horizontal: 35),
                  decoration: const BoxDecoration(
                      color: Color(0xFFFFFFFF),
                      borderRadius: BorderRadius.all(Radius.circular(16))),
                  child: Center(
                    child: Text(
                      message,
                      textAlign: TextAlign.center,
                      style: TextStyle(
                          fontSize: 14,
                          fontWeight: FontWeight.w500,
                          color: success ? AppColor.chartActiveColor : AppColor.redColor),
                    ),
                  ),
                )
              ],
            ),
            Positioned(
              bottom: Platform.isAndroid ? 8 : 20,
              left: 0,
              right: 0,
              child: AppButton(
                background: AppColor.custom_redColor,
                onTap: () {
                  Navigator.pop(context);
                },
                title: getString( "get_back"),
              ),
            )
          ],
        ),
      ),
    );
  }
}

==> soliq_id-1.4.37.tar.gz: lib/src/screens/widgets/message_screen.dart <==
import 'dart:io';
import 'dart:math' as math;

import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:soliq_id/src/data/model/response/compare_face_response.dart';

import '../../utils/assets.dart';
import '../../utils/color_utils.dart';
import '../../utils/faceid_localizations.dart';
import '../../utils/progress_indicator/src/circular_step_progress_indicator.dart';
import 'custom_button.dart';


class MessageScreen extends StatelessWidget {
  final CompareFaceResponse compareFaceResponse;

  const MessageScreen({
    Key? key,
    required this.compareFaceResponse,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: SafeArea(
        child: Stack(
          children: [
            Column(
              children: [
                Container(
                  margin: const EdgeInsets.all(35),
                  child: AspectRatio(
                      aspectRatio: 1.0 / 1,
                      child: CircularStepProgressIndicator(
                        totalSteps: 100,
                        currentStep: 100,
                        stepSize: 15,
                         selectedColor: compareFaceResponse.success
                            ? AppColor.chartActiveColor
                            : AppColor.redColor,
                        unselectedColor: Colors.transparent,
                        padding: math.pi / 35,
                        child: Container(
                          margin: const EdgeInsets.symmetric(
                              horizontal: 70, vertical: 80),
                          child: SvgPicture.asset(compareFaceResponse.success ? Assets.success_face : Assets.error_face),
                        ),
                      )),
                ),
                const SizedBox(
                  height: 30,
                ),
                Container(
                  height: 45,
                  width: MediaQuery.of(context).size.width,
                  margin: const EdgeInsets.symmetric(horizontal: 35),
                  decoration: const BoxDecoration(
                      color: Color(0xFFFFFFFF),
                      borderRadius: BorderRadius.all(Radius.circular(16))),
                  child: Center(
                    child: Text(
                      compareFaceResponse.message,
                      textAlign: TextAlign.center,
                      style: TextStyle(
                          fontSize: 14,
                          fontWeight: FontWeight.w500,
                          color: compareFaceResponse.success ? AppColor.chartActiveColor : AppColor.redColor),
                    ),
                  ),
                )
              ],
            ),
            Positioned(
              bottom: Platform.isAndroid ? 8 : 20,
              left: 0,
              right: 0,
              child: AppButton(
                onTap: () {
                  Navigator.pop(context, compareFaceResponse);
                },
                title: "Назад",
              ),
            )
          ],
        ),
      ),
    );
  }
}
